--
-- Name: Shuttle Control
-- Description: Shuttle implementation for steerables
-- Version: 2.0
-- Author: Templaer
-- Date: 10/04/2011
--

ShuttleControl = {}

-- Extended original functions --
function ShuttleControl:load(xmlFile) 
	self.setShuttleDirection = ShuttleControl.setShuttleDirection;
	self.setShuttleEnabled = ShuttleControl.setShuttleEnabled;
	
	self.shuttleOverride = Utils.getNoNil(getXMLBool(xmlFile, "vehicle.shuttleControl#override"), false);
	self.shuttleEnabled = true;
	self.shuttleDirection = 1;
end;

function ShuttleControl:readStream(streamId, connection)
	local shuttleDirection = streamReadInt32(streamId);
	self:setShuttleDirection(shuttleDirection, true);	
	
	local shuttleEnabled = streamReadBool(streamId);
	self:setShuttleEnabled(shuttleEnabled, true);
end;

function ShuttleControl:writeStream(streamId, connection)
	streamWriteInt32(streamId, self.shuttleDirection);	
	streamWriteBool(streamId, self.shuttleEnabled);	
end;

function ShuttleControl:update(dt) 
	if not self.shuttleOverride then
		if self:getIsActiveForInput() then
			if InputBinding.hasEvent(InputBinding.TOGGLE_SHUTTLE) then
				self:setShuttleEnabled(not self.shuttleEnabled);
			end;
		end;
		
		if self.shuttleEnabled then
			if self:getIsActiveForInput() then
				if InputBinding.hasEvent(InputBinding.CHANGE_DIRECTION) then
					self:setShuttleDirection(-self.shuttleDirection);
				end;
			end;
		end;
	end;
end;

function ShuttleControl:draw() 
	if not self.shuttleOverride then
		
	
		if self.shuttleEnabled then
			if self.shuttleDirection == 1 then
				g_currentMission:addHelpButtonText(g_i18n:getText("Shuttle_control_forwards"), InputBinding.CHANGE_DIRECTION);
			else
				g_currentMission:addHelpButtonText(g_i18n:getText("Shuttle_control_backwards"), InputBinding.CHANGE_DIRECTION);
			end;
		end;	
	end;
end;

-- New functions --
function ShuttleControl:setShuttleDirection(shuttleDirection, noEventSend) 
	SetShuttleDirectionEvent.sendEvent(self, shuttleDirection, noEventSend);
	self.shuttleDirection = shuttleDirection;
end;

function ShuttleControl:setShuttleEnabled(shuttleEnabled, noEventSend)
	SetShuttleEnabledEvent.sendEvent(self, shuttleEnabled, noEventSend);
	self.shuttleEnabled = shuttleEnabled;
end;

-- Append the functions to the original functions --
Steerable.load = Utils.appendedFunction(Steerable.load, ShuttleControl.load);
Steerable.readStream = Utils.appendedFunction(Steerable.readStream, ShuttleControl.readStream);
Steerable.writeStream = Utils.appendedFunction(Steerable.writeStream, ShuttleControl.writeStream);
Steerable.update = Utils.appendedFunction(Steerable.update, ShuttleControl.update);
Steerable.draw = Utils.appendedFunction(Steerable.draw, ShuttleControl.draw);

